MatchMakerMonitoring.fixed_width — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMakerMonitoring.fixed_width

property MatchMakerMonitoring.fixed_width: str

  Custom value for defining a fixed width of the page. Only takes effect, if the experiment is set to generally operate with a fixed page width in config.conf (option responsive in section layout must be “false”). Must be a string including a unit, e.g. “900px”. Can be defined as a class attribute.